# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.1.0~6647324',
    built_at='2023-12-05 17:41:11Z',
    sha='6647324f52d8be83435ceba1cd98111ae5e814bf',
    branch='HEAD',
    tag='v4.1.0',
)
